//
//  AttachmentView.swift
//  Tusker
//
//  Created by Shadowfacts on 8/31/18.
//  Copyright © 2018 Shadowfacts. All rights reserved.
//

import UIKit
import Pachyderm
import Gifu

protocol AttachmentViewDelegate {
    func showAttachmentsGallery(startingAt index: Int)
}

class AttachmentView: UIImageView, GIFAnimatable {
    
    var delegate: AttachmentViewDelegate?
    
    var attachment: Attachment!
    var index: Int!
    
    var gifData: Data?

    public lazy var animator: Animator? = Animator(withDelegate: self)

    init(attachment: Attachment, index: Int) {
        super.init(image: nil)
        commonInit()
        
        self.attachment = attachment
        self.index = index
        loadImage()
    }
    
    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
        commonInit()
    }
    
    func commonInit() {
        contentMode = .scaleAspectFill
        layer.masksToBounds = true
        isUserInteractionEnabled = true
        addGestureRecognizer(UITapGestureRecognizer(target: self, action: #selector(imagePressed)))
    }
    
    func loadImage() {
        ImageCache.attachments.get(attachment.url) { (data) in
            guard let data = data else { return }
            DispatchQueue.main.async {
                if self.attachment.url.pathExtension == "gif" {
                    self.animate(withGIFData: data)
                    self.gifData = data
                } else {
                    self.image = UIImage(data: data)
                }
            }
        }
    }
    
    override func display(_ layer: CALayer) {
        updateImageIfNeeded()
    }
    
    @objc func imagePressed() {
//        delegate?.showLargeAttachment(for: self)
        delegate?.showAttachmentsGallery(startingAt: index)
    }

}
